==> owncloud-10.0.3.tgz: owncloud/lib/l10n/eu.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hau normalean konpondu daitekesweb zerbitzarira config karpetan idazteko baimenak emanez",
    "See %s" : "Ikusi %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Hau normalean konpondu daiteke %sweb zerbitzarira config karpetan idazteko baimenak emanez%s.",
    "Sample configuration detected" : "Adibide-ezarpena detektatua",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detektatu da adibide-ezarpena kopiatu dela. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
    "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
    "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
    "Following databases are supported: %s" : "Hurrengo datubaseak onartzen dira: %s",
    "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
    "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
    "Library %s with a version higher than %s is required - available version %s." : "%s liburutegiak %s baino bertsio handiagoa izan behar du - dagoen bertsioa %s.",
    "Library %s with a version lower than %s is required - available version %s." : "%s liburutegiak %s baino bertsio txikiagoa izan behar du - dagoen bertsioa %s.",
    "Following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
    "ownCloud %s or higher is required." : "ownCloud %s edo haundiagoa behar da.",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "today" : "gaur",
    "yesterday" : "atzo",
    "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
    "last month" : "joan den hilabetean",
    "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
    "last year" : "joan den urtean",
    "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
    "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
    "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
    "seconds ago" : "segundu",
    "None" : "Ezer",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "File name contains at least one invalid character" : "Fitxategi izenak behintzat baliogabeko karaktere bat du",
    "App directory already exists" : "Aplikazioaren karpeta dagoeneko existitzen da",
    "Can't create app folder. Please fix permissions. %s" : "Ezin izan da aplikazioaren karpeta sortu. Mesdez konpondu baimenak. %s",
    "No source specified when installing app" : "Ez da jatorririk zehaztu aplikazioa instalatzerakoan",
    "No href specified when installing app from http" : "Ez da href parametrorik zehaztu http bidez aplikazioa instalatzerakoan",
    "No path specified when installing app from local file" : "Ez da kokalekurik zehaztu fitxategi lokal moduan aplikazioa instalatzerakoan",
    "Archives of type %s are not supported" : "%s motako fitxategiak ez dira onartzen",
    "Failed to open archive when installing app" : "Fitxategia irekitzeak huts egin du aplikazioa instalatzerakoan",
    "App does not provide an info.xml file" : "Aplikazioak ez du info.xml fitxategia",
    "App can't be installed because of not allowed code in the App" : "Aplikazioa ezin da instalatu bertan duen baimendu gabeko kodea dela eta",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikazioa ezin da instalatu ownCloud bertsio honekin bateragarria ez delako",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikazioa ezin da instalatu <shipped>true</shipped> etiketa duelako eta etiketa hau ez da onartzen banaketan ez datozen aplikazioetan",
    "Apps" : "Aplikazioak",
    "General" : "Orokorra",
    "Storage" : "Biltegiratzea",
    "Security" : "Segurtasuna",
    "Encryption" : "Enkriptazioa",
    "Sharing" : "Partekatzea",
    "Search" : "Bilatu",
    "Updates" : "Eguneraketak",
    "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
    "%s enter the database name." : "%s sartu datu basearen izena.",
    "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
    "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
    "Oracle username and/or password not valid" : "Oracle erabiltzaile edota pasahitza ez dira egokiak.",
    "DB Error: \"%s\"" : "DB errorea: \"%s\"",
    "Offending command was: \"%s\"" : "Errorea komando honek sortu du: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Existitzen den kontu bat edo administradorearena jarri behar duzu.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Errorea komando honek sortu du: \"%s\", izena: %s, pasahitza: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzaile edota pasahitza ez dira egokiak.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez ezabatu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
    "Set an admin password." : "Ezarri administraziorako pasahitza.",
    "Can't create or write into the data directory %s" : "Ezin da %s datu karpeta sortu edo bertan idatzi ",
    "%s shared »%s« with you" : "%s-ek »%s« zurekin partekatu du",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s partekatzeak huts egin du, motorrak %i motako partekatzeak baimentzen ez dituelako",
    "Sharing %s failed, because the file does not exist" : "%s elkarbanatzeak huts egin du, fitxategia ez delako existitzen",
    "You are not allowed to share %s" : "Ez zadue %s elkarbanatzeko baimendua",
    "Sharing %s failed, because the user %s does not exist" : "%s elkarbanatzeak huts egin du, %s erabiltzailea existitzen ez delako",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s elkarbanatzeak huts egin du, %s erabiltzailea ez delako %s partaide den talderen bateko partaidea",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Sharing %s failed, because the group %s does not exist" : "%s elkarbanatzeak huts egin du, %s taldea ez delako existitzen",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s elkarbanatzeak huts egin du, %s ez delako %s taldearen partaidea",
    "You need to provide a password to create a public link, only protected links are allowed" : "Lotura publiko bat sortzeko pasahitza idatzi behar duzu, bakarrik babestutako loturak baimenduta daude",
    "Sharing %s failed, because sharing with links is not allowed" : "%s elkarbanatzeak huts egin du, lotura bidezko elkarbanatzea baimendua ez dagoelako",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s partekatzeak huts egin du, ezin da %s aurkitu, agian zerbitzaria orain ez dago eskuragarri.",
    "Share type %s is not valid for %s" : "%s elkarbanaketa mota ez da %srentzako egokia",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%srentzako baimenak ezartzea huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Setting permissions for %s failed, because the item was not found" : "%srentzako baimenak ezartzea huts egin du, aurkitu ez delako",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ezin izan da jarri iraungitze data. Konpartitzea ezin da iraungi konpartitu eta %s ondoren.",
    "Cannot set expiration date. Expiration date is in the past" : "Ezin da jarri iraungitze data. Iraungitze data iragan da.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s elkarbanaketa motorra  OCP\\Share_Backend interfazea inplementatu behar du ",
    "Sharing backend %s not found" : "Ez da %s elkarbanaketa motorra aurkitu",
    "Sharing backend for %s not found" : "Ez da %srako elkarbanaketa motorrik aurkitu",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s elkarbanatzeak huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Sharing %s failed, because resharing is not allowed" : "%s elkarbanatzeak huts egin du, ber-elkarbanatzea baimenduta ez dagoelako",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s elkarbanatzeak huts egin du, %sren elkarbanaketa motorrak bere iturria aurkitu ezin duelako",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s elkarbanatzeak huts egin du, fitxategia katxean aurkitu ez delako",
    "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
    "Help" : "Laguntza",
    "Settings" : "Ezarpenak",
    "Users" : "Erabiltzaileak",
    "web services under your control" : "web zerbitzuak zure kontrolpean",
    "Application is not enabled" : "Aplikazioa ez dago gaituta",
    "Authentication error" : "Autentifikazio errorea",
    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
    "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
    "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hau normalean konpondu daiteke %sweb zerbitzarira apps karpetan idazteko baimenak emanez%s edo konfigurazio fitxategian appstorea ez gaituz.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Hau normalean konpondu daiteke %sweb zerbitzarira erro karpetan idazteko baimenak emanez%s.",
    "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
    "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren kudeatzaileari modulua instala dezan.",
    "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik faltan bezala markatuta daude?",
    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren kudeatzaileari web zerbitzaria berrabiarazteko.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
    "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Mesedez egiaztatu data karpeta \".ocdata\" fitxategia duela bere erroan.",
    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/eu.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hau normalean konpondu daitekesweb zerbitzarira config karpetan idazteko baimenak emanez",
    "See %s" : "Ikusi %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Hau normalean konpondu daiteke %sweb zerbitzarira config karpetan idazteko baimenak emanez%s.",
    "Sample configuration detected" : "Adibide-ezarpena detektatua",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detektatu da adibide-ezarpena kopiatu dela. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
    "PHP %s or higher is required." : "PHP %s edo berriagoa behar da.",
    "PHP with a version lower than %s is required." : "PHPren bertsioa %s baino txikiagoa izan behar da.",
    "Following databases are supported: %s" : "Hurrengo datubaseak onartzen dira: %s",
    "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
    "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
    "Library %s with a version higher than %s is required - available version %s." : "%s liburutegiak %s baino bertsio handiagoa izan behar du - dagoen bertsioa %s.",
    "Library %s with a version lower than %s is required - available version %s." : "%s liburutegiak %s baino bertsio txikiagoa izan behar du - dagoen bertsioa %s.",
    "Following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
    "ownCloud %s or higher is required." : "ownCloud %s edo haundiagoa behar da.",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "today" : "gaur",
    "yesterday" : "atzo",
    "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
    "last month" : "joan den hilabetean",
    "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
    "last year" : "joan den urtean",
    "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
    "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
    "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
    "seconds ago" : "segundu",
    "None" : "Ezer",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "File name contains at least one invalid character" : "Fitxategi izenak behintzat baliogabeko karaktere bat du",
    "App directory already exists" : "Aplikazioaren karpeta dagoeneko existitzen da",
    "Can't create app folder. Please fix permissions. %s" : "Ezin izan da aplikazioaren karpeta sortu. Mesdez konpondu baimenak. %s",
    "No source specified when installing app" : "Ez da jatorririk zehaztu aplikazioa instalatzerakoan",
    "No href specified when installing app from http" : "Ez da href parametrorik zehaztu http bidez aplikazioa instalatzerakoan",
    "No path specified when installing app from local file" : "Ez da kokalekurik zehaztu fitxategi lokal moduan aplikazioa instalatzerakoan",
    "Archives of type %s are not supported" : "%s motako fitxategiak ez dira onartzen",
    "Failed to open archive when installing app" : "Fitxategia irekitzeak huts egin du aplikazioa instalatzerakoan",
    "App does not provide an info.xml file" : "Aplikazioak ez du info.xml fitxategia",
    "App can't be installed because of not allowed code in the App" : "Aplikazioa ezin da instalatu bertan duen baimendu gabeko kodea dela eta",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikazioa ezin da instalatu ownCloud bertsio honekin bateragarria ez delako",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikazioa ezin da instalatu <shipped>true</shipped> etiketa duelako eta etiketa hau ez da onartzen banaketan ez datozen aplikazioetan",
    "Apps" : "Aplikazioak",
    "General" : "Orokorra",
    "Storage" : "Biltegiratzea",
    "Security" : "Segurtasuna",
    "Encryption" : "Enkriptazioa",
    "Sharing" : "Partekatzea",
    "Search" : "Bilatu",
    "Updates" : "Eguneraketak",
    "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
    "%s enter the database name." : "%s sartu datu basearen izena.",
    "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
    "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
    "Oracle username and/or password not valid" : "Oracle erabiltzaile edota pasahitza ez dira egokiak.",
    "DB Error: \"%s\"" : "DB errorea: \"%s\"",
    "Offending command was: \"%s\"" : "Errorea komando honek sortu du: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Existitzen den kontu bat edo administradorearena jarri behar duzu.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Errorea komando honek sortu du: \"%s\", izena: %s, pasahitza: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzaile edota pasahitza ez dira egokiak.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez ezabatu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
    "Set an admin password." : "Ezarri administraziorako pasahitza.",
    "Can't create or write into the data directory %s" : "Ezin da %s datu karpeta sortu edo bertan idatzi ",
    "%s shared »%s« with you" : "%s-ek »%s« zurekin partekatu du",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s partekatzeak huts egin du, motorrak %i motako partekatzeak baimentzen ez dituelako",
    "Sharing %s failed, because the file does not exist" : "%s elkarbanatzeak huts egin du, fitxategia ez delako existitzen",
    "You are not allowed to share %s" : "Ez zadue %s elkarbanatzeko baimendua",
    "Sharing %s failed, because the user %s does not exist" : "%s elkarbanatzeak huts egin du, %s erabiltzailea existitzen ez delako",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s elkarbanatzeak huts egin du, %s erabiltzailea ez delako %s partaide den talderen bateko partaidea",
    "Sharing %s failed, because this item is already shared with %s" : "%s elkarbanatzeak huts egin du, dagoeneko %s erabiltzailearekin elkarbanatuta dagoelako",
    "Sharing %s failed, because the group %s does not exist" : "%s elkarbanatzeak huts egin du, %s taldea ez delako existitzen",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s elkarbanatzeak huts egin du, %s ez delako %s taldearen partaidea",
    "You need to provide a password to create a public link, only protected links are allowed" : "Lotura publiko bat sortzeko pasahitza idatzi behar duzu, bakarrik babestutako loturak baimenduta daude",
    "Sharing %s failed, because sharing with links is not allowed" : "%s elkarbanatzeak huts egin du, lotura bidezko elkarbanatzea baimendua ez dagoelako",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s partekatzeak huts egin du, ezin da %s aurkitu, agian zerbitzaria orain ez dago eskuragarri.",
    "Share type %s is not valid for %s" : "%s elkarbanaketa mota ez da %srentzako egokia",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%srentzako baimenak ezartzea huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Setting permissions for %s failed, because the item was not found" : "%srentzako baimenak ezartzea huts egin du, aurkitu ez delako",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ezin izan da jarri iraungitze data. Konpartitzea ezin da iraungi konpartitu eta %s ondoren.",
    "Cannot set expiration date. Expiration date is in the past" : "Ezin da jarri iraungitze data. Iraungitze data iragan da.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s elkarbanaketa motorra  OCP\\Share_Backend interfazea inplementatu behar du ",
    "Sharing backend %s not found" : "Ez da %s elkarbanaketa motorra aurkitu",
    "Sharing backend for %s not found" : "Ez da %srako elkarbanaketa motorrik aurkitu",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s elkarbanatzeak huts egin du, baimenak %sri emandakoak baino gehiago direlako",
    "Sharing %s failed, because resharing is not allowed" : "%s elkarbanatzeak huts egin du, ber-elkarbanatzea baimenduta ez dagoelako",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s elkarbanatzeak huts egin du, %sren elkarbanaketa motorrak bere iturria aurkitu ezin duelako",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s elkarbanatzeak huts egin du, fitxategia katxean aurkitu ez delako",
    "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
    "Help" : "Laguntza",
    "Settings" : "Ezarpenak",
    "Users" : "Erabiltzaileak",
    "web services under your control" : "web zerbitzuak zure kontrolpean",
    "Application is not enabled" : "Aplikazioa ez dago gaituta",
    "Authentication error" : "Autentifikazio errorea",
    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
    "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
    "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hau normalean konpondu daiteke %sweb zerbitzarira apps karpetan idazteko baimenak emanez%s edo konfigurazio fitxategian appstorea ez gaituz.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Hau normalean konpondu daiteke %sweb zerbitzarira erro karpetan idazteko baimenak emanez%s.",
    "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
    "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren kudeatzaileari modulua instala dezan.",
    "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik faltan bezala markatuta daude?",
    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren kudeatzaileari web zerbitzaria berrabiarazteko.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
    "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Mesedez egiaztatu data karpeta \".ocdata\" fitxategia duela bere erroan.",
    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an.",
    "Imprint" : "Imprint",
    "__language_name__" : "Euskara"
},
"nplurals=2; plural=(n != 1);");
